@@ -17,7 +17,7 @@ class OpenRedisDialog(QDialog):
 
     def _create_redis(self):
         if self.exec_() != QDialog.Accepted:
-            return
+            return None, None
         kwargs = dict(db=self.ui.db.value())
         client_name = self.ui.name.text()
         user = self.ui.user.text()
@@ -40,12 +40,16 @@ class OpenRedisDialog(QDialog):
                 kwargs["host"] = host
         else:
             kwargs["unix_socket_path"] = self.ui.socket.text()
-        return QRedis(**kwargs)
+        opts = dict(
+            filter=self.ui.filter.text(),
+            split_by=self.ui.splitter.text(),
+        )
+        return QRedis(**kwargs), opts
 
     @classmethod
-    def create_redis(cls):
+    def create_redis(cls, parent=None):
         if cls.Dialog is None:
-            cls.Dialog = cls()
+            cls.Dialog = cls(parent=parent)
         return cls.Dialog._create_redis()
 
 
