@@ -2,7 +2,6 @@ import os
 import sys
 import collections
 
-KeyItem = collections.namedtuple("KeyItem", "redis key type ttl value")
 
 REDIS_TEXT = """\
 Db: {db}
@@ -10,6 +9,18 @@ Address: {addr}
 Client ID: {id}
 Client Name: {name}"""
 
+
+def toolTip(item):
+    return f"""\
+name: {item.key}
+type: {item.type}
+TTL: {item.ttl}"""
+
+
+KeyItem = collections.namedtuple("KeyItem", "redis key type ttl value")
+KeyItem.toolTip = toolTip
+
+
 def redis_str(redis):
     info = redis.connection_pool.connection_kwargs
     db = info["db"]
@@ -44,10 +55,10 @@ def redis_value(redis, key, dtype=None):
 def redis_key_split(key, chars="."):
     result, curr = [], ""
     for char in key:
-        if str(char) in chars:
+        if char in chars:
             result.append(curr)
             curr = ""
-        curr += str(char)
+        curr += char
     if curr:
         result.append(curr)
     return result
